@@ -15,13 +15,13 @@ class PipelineMessageHandler(ABC):
         self._submitter = DeferredTaskSubmitter(self._graph, serialiser)
         self._result_aggregator = ResultAggregator(self._graph, serialiser)
         self._result_emitter = ResultEmitter()
-        
+
     @abstractmethod
     def can_handle_message(self, context: TaskContext, message: Union[TaskRequest, TaskResult, TaskException]) -> bool:
         pass
 
     @abstractmethod
-    async def handle_message(self, context: TaskContext, message: Union[TaskRequest, TaskResult, TaskException], pipeline: '_Pipeline', state: Any = None) -> Tuple[bool, Union[TaskRequest, TaskResult, TaskException]]:
+    def handle_message(self, context: TaskContext, message: Union[TaskRequest, TaskResult, TaskException], pipeline: '_Pipeline', task_state: Any = None) -> Tuple[bool, Union[TaskRequest, TaskResult, TaskException]]:
         pass
     
     @property
