@@ -1,4 +1,5 @@
 from statefun_tasks.context import TaskContext
+from statefun_tasks.events.event_handlers import EventHandlers
 from statefun_tasks.pipeline_builder import PipelineBuilder
 from statefun_tasks.utils import _is_tuple, _type_name, _annotated_protos_for
 from statefun_tasks.messages_pb2 import TaskRequest
@@ -9,14 +10,15 @@ import asyncio
 
 
 class FlinkTask(object):
-    def __init__(self, fun, serialiser, retry_policy=None, with_state=False, is_fruitful=True, with_context=False, **kwargs):
+    def __init__(self, fun, serialiser, events:EventHandlers, retry_policy=None, with_state=False, is_fruitful=True, with_context=False, **kwargs):
         self._fun = fun
         self._serialiser = serialiser
         self._retry_policy = retry_policy
         self._with_state = with_state
         self._is_fruitful = is_fruitful
         self._with_context = with_context
-
+        self._events = events
+        
         full_arg_spec = inspect.getfullargspec(fun)
         self._args = full_arg_spec.args
         self._default_args = full_arg_spec.defaults
@@ -77,7 +79,7 @@ class FlinkTask(object):
         if isinstance(fn_result, PipelineBuilder):
             # this new pipeline which once complete will yield the result of the whole pipeline
             # back to the caller as if it were a simple task
-            pipeline = fn_result.to_pipeline(self._serialiser, is_fruitful=is_fruitful)
+            pipeline = fn_result.to_pipeline(serialiser=self._serialiser, is_fruitful=is_fruitful, events=self._events)
             fn_result = ()
 
         # drop the result if the task is marked as not fruitful or caller has asked for the result to be dropped
@@ -137,6 +139,8 @@ class FlinkTask(object):
                     raise ValueError('Not enough args supplied')
                 resolved_args.append(self._default_args[default_arg_index])
             else:
+                if len(args) == 0:
+                    raise ValueError('Not enough args supplied')
                 resolved_args.append(args.pop(0))
         if self._accepts_varargs:
             resolved_args.extend(args)
